@@ -8,7 +8,7 @@ use Pod::Usage;
 use Bio::ToolBox::Data::Stream;
 use Bio::ToolBox::utility;
 use Bio::ToolBox::big_helper qw(bed_to_bigbed_conversion);
-my $VERSION =  '1.34';
+my $VERSION =  '1.54';
 
 print "\n This program will write a BED file\n";
 
@@ -35,6 +35,7 @@ my (
 	$score_index,
 	$strand_index,
 	$zero_based,
+	$no_header,
 	$ask,
 	$bigbed,
 	$bb_app_path,
@@ -49,6 +50,8 @@ my (
 GetOptions( 
 	'in=s'      => \$infile, # the solexa data file
 	'out=s'     => \$outfile, # name of output file 
+	'noheader'  => \$no_header, # source has no header line
+	'ask'       => \$ask, # request help in assigning indices
 	'chr=i'     => \$chr_index, # index of the chromosome column
 	'start=i'   => \$start_index, # index of the start position column
 	'stop|end=i'=> \$stop_index, # index of the stop position coloumn
@@ -56,7 +59,6 @@ GetOptions(
 	'score=i'   => \$score_index, # index for the score column
 	'strand=i'  => \$strand_index, # index for the strand column
 	'zero!'     => \$zero_based, # source is 0-based numbering, convert
-	'ask'       => \$ask, # request help in assigning indices
 	'bigbed|bb' => \$bigbed, # generate a binary bigbed file
 	'db=s'      => \$database, # database for bigbed file generation
 	'chromof=s' => \$chromo_file, # name of a chromosome file
@@ -116,7 +118,7 @@ if (defined $name) {
 
 
 ### Load file
-my $Input = Bio::ToolBox::Data::Stream->new(file => $infile) or
+my $Input = Bio::ToolBox::Data::Stream->new(file => $infile, noheader => $no_header) or
 	die "Unable to open file '$infile'!\n";
 
 if ($bigbed) {
@@ -340,6 +342,7 @@ data2bed.pl [--options...] <filename>
   
   Options:
   --in <filename>
+  --noheader
   --ask
   --chr <column_index>
   --start <column_index>
@@ -373,6 +376,11 @@ coordinates are required. The first row should be column headers. Text
 files generated by other B<BioToolBox> scripts are acceptable. Files may 
 be gzipped compressed.
 
+=item --noheader
+
+The input file does not have column headers, often found with UCSC 
+derived annotation data tables. 
+
 =item --ask
 
 Indicate that the program should interactively ask for the indices for 
