@@ -18,7 +18,7 @@ eval {
 	require Parallel::ForkManager;
 	$parallel = 1;
 };
-my $VERSION = '1.53';
+my $VERSION = '1.54';
 
 print "\n This script will collect binned values across features\n\n";
 
@@ -126,7 +126,12 @@ if ($infile) {
 		feature    => $feature,
 		subfeature => $subfeature,
 	) or die " unable to load input file '$infile'\n";
-	printf " Loaded %s features from $infile.\n", format_with_commas( $Data->last_row );
+	if ($Data->last_row) {
+		printf " Loaded %s features from $infile.\n", format_with_commas( $Data->last_row );
+	}
+	else {
+		die " No features loaded!\n";
+	}
 	
 	# update main database as necessary
 	if ($main_database) {
