@@ -21,7 +21,7 @@ eval {
 	$parallel = 1;
 };
 
-my $VERSION = '1.53';
+my $VERSION = '1.54';
 
 
 print "\n A program to collect data for a list of features\n\n";
@@ -139,7 +139,12 @@ if ($infile) {
 		feature    => $feature,
 		subfeature => $subfeature,
 	) or die " unable to load input file '$infile'\n";
-	printf " Loaded %s features from $infile.\n", format_with_commas( $Data->last_row );
+	if ($Data->last_row) {
+		printf " Loaded %s features from $infile.\n", format_with_commas( $Data->last_row );
+	}
+	else {
+		die " No features loaded!\n";
+	}
 	
 	# update main database as necessary
 	if ($main_database) {
@@ -473,8 +478,12 @@ sub parallel_execution {
 		}
 		
 		# collapse transcripts if needed
-		if ($feature eq 'gene' and $subfeature eq 'exon') {
-			$Data->collapse_gene_transcripts;
+		if ($feature =~ /^gene/i and $subfeature eq 'exon') {
+			my $c = $Data->collapse_gene_transcripts;
+			if ($c != $Data->last_row) {
+				printf " Not all row SeqFeatures could be collapsed, %d failed\n", 
+					$Data->last_row - $c;
+			}
 		}
 		
 		# collect the dataset
@@ -517,8 +526,12 @@ sub parallel_execution {
 sub single_execution {
 	
 	# collapse transcripts if needed
-	if ($feature eq 'gene' and $subfeature eq 'exon') {
-		$Data->collapse_gene_transcripts;
+	if ($feature =~ /^gene/i and $subfeature eq 'exon') {
+		my $c = $Data->collapse_gene_transcripts;
+		if ($c != $Data->last_row) {
+			printf " Not all row SeqFeatures could be collapsed, %d failed\n", 
+				$Data->last_row - $c;
+		}
 	}
 		
 	# collect the datasets
