@@ -25,7 +25,7 @@ use constant DATASET_HASH_LIMIT => 20001;
 		# region, and a hash returned with potentially a score for each basepair. 
 		# This may become unwieldy for very large regions, which may be better 
 		# served by separate database queries for each window.
-my $VERSION = '1.53';
+my $VERSION = '1.54';
 
 print "\n A script to collect windowed data flanking a relative position of a feature\n\n";
   
@@ -135,7 +135,12 @@ if ($infile) {
 		parse      => 1,
 		feature    => $feature || 'gene',
 	) or die " unable to load input file '$infile'\n";
-	printf " Loaded %s features from $infile.\n", format_with_commas( $Data->last_row );
+	if ($Data->last_row) {
+		printf " Loaded %s features from $infile.\n", format_with_commas( $Data->last_row );
+	}
+	else {
+		die " No features loaded!\n";
+	}
 	
 	# update main database as necessary
 	if ($main_database) {
